Type: Package
Title: Import Various Northern and Southern Hemisphere Climate Indices
Version: 0.5.7
Description: Downloads Southern Oscillation Index, Oceanic Nino Index, North Pacific Gyre Oscillation data, North Atlantic Oscillation and Arctic Oscillation. Data sources are described in the help files for each function.
License: GPL (≥ 3)
URL: https://boshek.github.io/rsoi/, https://github.com/boshek/rsoi
Depends: R (≥ 3.3.0)
Imports: curl, memoise, stats, utils
Suggests: testthat (≥ 2.1.0), tibble
Encoding: UTF-8
RoxygenNote: 7.3.3
BugReports: https://github.com/boshek/rsoi/issues
NeedsCompilation: no
Packaged: 2026-03-05 18:53:56 UTC; sam.albers
Author: Sam Albers [aut, cre], Elio Campitelli [ctb]
Maintainer: Sam Albers <sam.albers@gmail.com>
Repository: CRAN
Date/Publication: 2026-03-06 08:20:02 UTC

El Nino/Southern Oscillation (ENSO) and Related Climate Indices

Description

Downloads Southern Oscillation Index, Oceanic Nino Index, North Pacific Gyre Oscillation data, North Atlantic Oscillation and Arctic Oscillation. Data sources are described in the help files for each function.

Author(s)

Maintainer: Sam Albers sam.albers@gmail.com

Other contributors:

See Also

Useful links:


Download Antarctic Oscillation data

Description

Projection of the monthly 700 hPa anomaly height field south of 20°S on the first EOF obtained from the monthly 700 hPa height anomaly.

Usage

download_aao(use_cache = FALSE, file = NULL)

Arguments

use_cache

logical option to save and load from cache. If 'TRUE', results will be cached in memory if 'file' is 'NULL' or on disk if 'file' is not 'NULL'.

file

optional character with the full path of a file to save the data. If 'cache' is 'FALSE' but 'file' is not 'NULL', the results will be downloaded from the internet and saved on disk.

Value

References

https://www.cpc.ncep.noaa.gov/products/precip/CWlink/daily_ao_index/aao/aao.shtml

Examples

## Not run: 
aao <- download_aao()

## End(Not run)


Download Arctic Oscillation data

Description

Projection of the daily 1000 hPa anomaly height field north of 20°N on the first EOF obtained from the monthly 1000 hPa height anomaly.

Usage

download_ao(use_cache = FALSE, file = NULL)

Arguments

use_cache

logical option to save and load from cache. If 'TRUE', results will be cached in memory if 'file' is 'NULL' or on disk if 'file' is not 'NULL'.

file

optional character with the full path of a file to save the data. If 'cache' is 'FALSE' but 'file' is not 'NULL', the results will be downloaded from the internet and saved on disk.

Value

References

https://www.ncei.noaa.gov/access/monitoring/ao/

Examples

## Not run: 
ao <- download_ao()

## End(Not run)


Download Asymmetric and Symmetric SAM indices

Description

Deprecated. The upstream API for the Asymmetric and Symmetric SAM indices is no longer available. These functions now return NULL with a warning.

Usage

download_asymsam_monthly(use_cache = FALSE, file = NULL)

download_asymsam_daily(use_cache = FALSE, file = NULL)

Arguments

use_cache

logical option to save and load from cache. If 'TRUE', results will be cached in memory if 'file' is 'NULL' or on disk if 'file' is not 'NULL'.

file

optional character with the full path of a file to save the data. If 'cache' is 'FALSE' but 'file' is not 'NULL', the results will be downloaded from the internet and saved on disk.

Value

NULL (invisibly). A warning is issued.

References

Campitelli, E., Diaz, L. B., & Vera, C. (2022). Assessment of zonally symmetric and asymmetric components of the Southern Annular Mode using a novel approach. Climate Dynamics, 58(1), 161-178. doi:10.1007/s00382-021-05896-5

Examples

## Not run: 
asymsam <- download_asymsam_monthly()

## End(Not run)


Download Dipole Mode Index (DMI)

Description

Intensity of the IOD is represented by anomalous SST gradient between the western equatorial Indian Ocean (50E-70E and 10S-10N) and the south eastern equatorial Indian Ocean (90E-110E and 10S-0N). This gradient is named as Dipole Mode Index (DMI). When the DMI is positive then, the phenomenon is refereed as the positive IOD and when it is negative, it is refereed as negative IOD.

Usage

download_dmi(use_cache = FALSE, file = NULL)

Arguments

use_cache

logical option to save and load from cache. If 'TRUE', results will be cached in memory if 'file' is 'NULL' or on disk if 'file' is not 'NULL'.

file

optional character with the full path of a file to save the data. If 'cache' is 'FALSE' but 'file' is not 'NULL', the results will be downloaded from the internet and saved on disk.

Value

References

https://psl.noaa.gov/gcos_wgsp/Timeseries/DMI/

Examples

## Not run: 
dmi <- download_dmi()

## End(Not run)


Download Southern Oscillation Index and Oceanic Nino Index data

Description

The Southern Oscillation Index is defined as the standardized difference between barometric readings at Darwin, Australia and Tahiti. The Oceanic Nino Index is average sea surface temperature in the Nino 3.4 region (120W to 170W) averaged over three months. Phases are categorized by Oceanic Nino Index:

Usage

download_enso(climate_idx = c("all", "soi", "oni", "npgo"), create_csv = FALSE)

Arguments

climate_idx

Choose which ENSO related climate index to output. Current arguments supported are soi (the Southern Oscillation Index), oni (the Oceanic Nino Index), npgo (the North Pacific Gyre Oscillation) and all. all outputs each supported index variable as a slimmer dataset than each individual climate index call.

create_csv

Logical option to create a local copy of the data. Defaults to FALSE.

Value

Examples

## Not run: 
enso <- download_enso()

## End(Not run)


Download Multivariate ENSO Index Version 2 (MEI.v2)

Description

MEI.v2 is based on EOF analysis of level pressure, sea surface temperature, surface zonal winds, surface meridional winds, and Outgoing Longwave Radiation. The analysis is conducted for 12 partially overlapping 2-month "seasons".

Warm phase is defined as MEI index greater or equal to 0.5. Cold phase is defined as MEI index lesser or equal to -0.5.

Usage

download_mei(use_cache = FALSE, file = NULL)

Arguments

use_cache

logical option to save and load from cache. If 'TRUE', results will be cached in memory if 'file' is 'NULL' or on disk if 'file' is not 'NULL'.

file

optional character with the full path of a file to save the data. If 'cache' is 'FALSE' but 'file' is not 'NULL', the results will be downloaded from the internet and saved on disk.

Value

References

https://psl.noaa.gov/enso/mei/

Examples

## Not run: 
mei <- download_mei()

## End(Not run)


Download North Atlantic Oscillation data

Description

surface sea-level pressure difference between the Subtropical (Azores) High and the Subpolar Low.

Usage

download_nao(use_cache = FALSE, file = NULL)

Arguments

use_cache

logical option to save and load from cache. If 'TRUE', results will be cached in memory if 'file' is 'NULL' or on disk if 'file' is not 'NULL'.

file

optional character with the full path of a file to save the data. If 'cache' is 'FALSE' but 'file' is not 'NULL', the results will be downloaded from the internet and saved on disk.

Value

References

https://www.ncei.noaa.gov/access/monitoring/nao/

Examples

## Not run: 
nao <- download_nao()

## End(Not run)


Download North Pacific Gyre Oscillation data

Description

North Pacific Gyre Oscillation data also known as the Victoria mode

Usage

download_npgo(use_cache = FALSE, file = NULL)

Arguments

use_cache

logical option to save and load from cache. If 'TRUE', results will be cached in memory if 'file' is 'NULL' or on disk if 'file' is not 'NULL'.

file

optional character with the full path of a file to save the data. If 'cache' is 'FALSE' but 'file' is not 'NULL', the results will be downloaded from the internet and saved on disk.

Value

References

https://www.oces.us/npgo/

Examples

## Not run: 
npgo <- download_npgo()

## End(Not run)

Download Oceanic Nino Index data

Description

The Oceanic Nino Index is average sea surface temperature in the Nino 3.4 region (120W to 170W) averaged over three months. Phases are categorized by Oceanic Nino Index:

Usage

download_oni(use_cache = FALSE, file = NULL)

Arguments

use_cache

logical option to save and load from cache. If 'TRUE', results will be cached in memory if 'file' is 'NULL' or on disk if 'file' is not 'NULL'.

file

optional character with the full path of a file to save the data. If 'cache' is 'FALSE' but 'file' is not 'NULL', the results will be downloaded from the internet and saved on disk.

Value

References

https://www.cpc.ncep.noaa.gov/products/precip/CWlink/MJO/enso.shtml

Examples

## Not run: 
oni <- download_oni()

## End(Not run)


Download Pacific Decadal Oscillation Data

Description

The PDO index is derived as the leading principal of monthly SST anomalies in the North Pacific Ocean, poleward of 20N. The monthly mean global average SST anomalies are removed to separate this pattern of variability from any "global warming" signal that may be present in the data.

The NCEI PDO index is based on NOAA's extended reconstruction of SSTs (ERSST Version 4). It is constructed by regressing the ERSST anomalies against the Mantua PDO index for their overlap period, to compute a PDO regression map for the North Pacific ERSST anomalies. The ERSST anomalies are then projected onto that map to compute the NCEI index. The NCEI PDO index closely follows the Mantua PDO index.

Usage

download_pdo(use_cache = FALSE, file = NULL)

Arguments

use_cache

logical option to save and load from cache. If 'TRUE', results will be cached in memory if 'file' is 'NULL' or on disk if 'file' is not 'NULL'.

file

optional character with the full path of a file to save the data. If 'cache' is 'FALSE' but 'file' is not 'NULL', the results will be downloaded from the internet and saved on disk.

Value

References

Original PDO: https://www.ncei.noaa.gov/access/monitoring/pdo/

Examples

## Not run: 
pdo <- download_pdo()

## End(Not run)


Download Relative Oceanic Nino Index data

Description

El Niño–Southern Oscillation (ENSO) is often characterized through the use of sea surface temperature (SST) departures from their climatological values, as in the Niño-3.4 index. However, this approach is problematic in a changing climate when the climatology itself is varying. To address this issue, van Oldenborgh et al. proposed a relative Niño-3.4 SST index, which subtracts the tropical mean SST anomaly from the Niño-3.4 index and multiplies by a scaling factor.

Usage

download_roni(use_cache = FALSE, file = NULL)

Arguments

use_cache

logical option to save and load from cache. If 'TRUE', results will be cached in memory if 'file' is 'NULL' or on disk if 'file' is not 'NULL'.

file

optional character with the full path of a file to save the data. If 'cache' is 'FALSE' but 'file' is not 'NULL', the results will be downloaded from the internet and saved on disk.

Value

References

https://www.cpc.ncep.noaa.gov/products/analysis_monitoring/enso/roni/#latest-data doi:10.1175/JCLI-D-23-0406.1

Examples

## Not run: 
roni <- download_roni()

## End(Not run)


Download Southern Oscillation Index data

Description

The Southern Oscillation Index is defined as the standardized difference between barometric readings at Darwin, Australia and Tahiti.

Usage

download_soi(use_cache = FALSE, file = NULL)

Arguments

use_cache

logical option to save and load from cache. If 'TRUE', results will be cached in memory if 'file' is 'NULL' or on disk if 'file' is not 'NULL'.

file

optional character with the full path of a file to save the data. If 'cache' is 'FALSE' but 'file' is not 'NULL', the results will be downloaded from the internet and saved on disk.

Value

References

https://www.cpc.ncep.noaa.gov/data/indices/soi

Examples

## Not run: 
soi <- download_soi()

## End(Not run)